//
//  YHEducationalQualificationVC.swift
//  galaxy
//
//  Created by edy on 2024/2/7.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit


class YHEducationalQualificationVC: YHBaseViewController {
    
    var orderId:Int?
    let educationRequest:YHEducationRequestViewModel = YHEducationRequestViewModel()
    var familyMemberInfo: YHFamilyMemberGroupInfo?
    var isChildsEditMode: YHFormTitleItemEditType = .none
    var isBrothersEditMode: YHFormTitleItemEditType = .none
    var educationInfo: YHEducationListInfo?
    var items:[[YHFormItemProtocol]] = []
    
    lazy var tableView: UITableView = {
        
        let tableView = UITableView(frame:.zero, style:.plain)
        
        if #available(iOS 11.0, *) {
            tableView.contentInsetAdjustmentBehavior = .never
        }
        tableView.showsVerticalScrollIndicator = false
        tableView.backgroundColor = .clear
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.register(YHEducationInfoCell.self, forCellReuseIdentifier: YHEducationInfoCell.cellReuseIdentifier)
        tableView.register(YHFormItemTitleCell.self, forCellReuseIdentifier: YHFormItemTitleCell.cellReuseIdentifier)
        tableView.register(YHFormItemAddCell.self, forCellReuseIdentifier: YHFormItemAddCell.cellReuseIdentifier)
        tableView.register(YHFormItemEnterDetailCell.self, forCellReuseIdentifier: YHFormItemEnterDetailCell.cellReuseIdentifier)
        tableView.register(YHFormItemAddCell.self, forCellReuseIdentifier: YHFormItemAddCell.cellReuseIdentifier)
        tableView.register(YHFormItemQuestionsCell.self, forCellReuseIdentifier: YHFormItemQuestionsCell.cellReuseIdentifier)
        return tableView
    }()
    
    var bottomView: YHSaveAndSubmitView = {
        let view = YHSaveAndSubmitView.createView()
        return view
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.gk_navTitle = "学历/专业资格填写".local
        view.backgroundColor = UIColor(hexString:"#F8F8F8")
        createUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
    }
    
    func createUI() {
        
        view.addSubview(tableView);
        view.addSubview(bottomView)
        
        bottomView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.bottom.equalToSuperview().offset(-k_Height_safeAreaInsetsBottom())
            make.height.equalTo(YHSaveAndSubmitView.height)
        }
        
        tableView.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(k_Height_NavigationtBarAndStatuBar)
            make.bottom.equalTo(bottomView.snp.top)
            make.left.equalToSuperview().offset(16)
            make.right.equalToSuperview().offset(-16)
        }
        
        loadInfo()
        requestEducationInfo()
    }
    
    func loadInfo() {
        
        guard let educationInfo = educationInfo else { return }
        
        items.removeAll()
        
        // 主申请人学历
        let title0 = YHFormTitleItem(type: .mainApplicantEducation)
        var arr0:[YHFormItemProtocol] = [title0]
        if let eduList = educationInfo.eduList {
            for (index, eduInfo) in eduList.enumerated() {
                let item = YHFormDetailItem(type: .educationInfo)
                arr0.append(item)
            }
        }
        // 新增学历信息
        arr0.append(YHFormAddItem(type: .addEducation))
        items.append(arr0)
        
        // 主申请人专业资格及会员资格
        let title1 = YHFormTitleItem(type: .mainApplicantProfessionalQualification)
        var arr1:[YHFormItemProtocol] = [title1]
        if let quaList = educationInfo.quaList {
            for (index, quaInfo) in quaList.enumerated() {
                let item = YHFormDetailItem(type: .certificateInfo)
                arr1.append(item)
            }
        }
        // 新增学历信息
        arr1.append(YHFormAddItem(type: .addCertificateInfo))
        items.append(arr1)
        
        // 学历证书姓名及出生日期正确性
        let title2 = YHFormTitleItem(type: .edutionalCertificateNameAndBirthday)
        var arr2:[YHFormItemProtocol] = [title2]
        // 问题集合
        let questions = YHQuestionInfo.getEducationQuestion()
        for questionInfo in questions {
            if questionInfo.key == "qualification" {
                questionInfo.answer = educationInfo.qualification
                
            } else if questionInfo.key == "graduate" {
                questionInfo.answer = educationInfo.graduate
            }
            arr2.append(questionInfo)
        }
        items.append(arr2)
        self.tableView.reloadData()
    }
}

extension YHEducationalQualificationVC : UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return items.count
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if section >= items.count { return 0 }
        let arr = items[section]
        return arr.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        if indexPath.section >= items.count { return createDefaultCell(indexPath) }
        let arr:[YHFormItemProtocol] = items[indexPath.section]
        if indexPath.row >= arr.count {  return createDefaultCell(indexPath) }
        let item:YHFormItemProtocol = arr[indexPath.row]

        if item is YHFormTitleItem { // 是标题
            
            let formItem = item as! YHFormTitleItem
            
            let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemTitleCell.cellReuseIdentifier, for: indexPath) as! YHFormItemTitleCell
            cell.titleLabel.text = formItem.getTitle()
            cell.subTitleLabel.text = formItem.getSubTitle()
            
            // 决定右边按钮显示样式
            cell.showEditType(type: .none)
//            if formItem.type == .child {
//                cell.showEditType(type: isChildsEditMode)
//                
//            } else if formItem.type == .brother {
//                cell.showEditType(type: isBrothersEditMode)
//            }
            
            // 右边按钮点击事件处理
            cell.rightClickBlock = { [weak self] type in
                
                guard let self = self else { return }
            }
            return cell
        }
        
        if item is YHFormAddItem {
            let detailItem = item as! YHFormAddItem
            let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemAddCell.cellReuseIdentifier, for: indexPath) as! YHFormItemAddCell
            if detailItem.type == .addEducation {
                cell.title = "新增学历信息"
                
            } else if detailItem.type == .addCertificateInfo {
                cell.title = "新增证书信息"
                
            } else {
                cell.title = ""
            }
            return cell
        }
        
        if item is YHQuestionInfo {
            
            let detailItem = item as! YHQuestionInfo
            let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemQuestionsCell.cellReuseIdentifier, for: indexPath) as! YHFormItemQuestionsCell
            cell.isMust = true
            cell.title =  String(format: "%d、\(detailItem.question)", indexPath.row)
            
            var select0 = false
            var select1 = false
            if detailItem.answer == 1 {
                select0 = true
                
            } else if detailItem.answer == 2 {
                select1 = true
            }
            
            let answers = [YHFormChoiceItem(title: "是".local, isSelect: select0),YHFormChoiceItem(title: "否".local, isSelect: select1)]
            cell.answerArr = answers
            return cell
        }
        
        if item is YHFormDetailItem {
            let detailItem = item as! YHFormDetailItem
            if detailItem.type == .educationInfo {
                if let eduList = educationInfo?.eduList {
                    // 第一行是标题
                    let eduInfo:YHEducationInfo = eduList[indexPath.row-1]
                    
                    if eduInfo.vacantNum > 0 {
                        let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemEnterDetailCell.cellReuseIdentifier, for: indexPath) as! YHFormItemEnterDetailCell
                        if let college = eduInfo.college, !college.isEmpty {
                            cell.title = eduInfo.college
                        } else {
                            cell.title = "学历标题".local
                        }
                        cell.detailLabel.text = String(format: "有%d项未填", eduInfo.vacantNum)
                        return cell
                        
                    } else {
                        
                        let cell = tableView.dequeueReusableCell(withIdentifier: YHEducationInfoCell.cellReuseIdentifier, for: indexPath) as! YHEducationInfoCell
                        cell.titleLabel.text = eduInfo.college
                        cell.subTitleLabel.text = ""
                        if let professional = eduInfo.professional, let background = eduInfo.background {
                            cell.subTitleLabel.text = String("\(background)-\(professional)")
                        }
                        cell.timeLabel.text = ""
                        if let admissionTime = eduInfo.admissionTime, let graduateTime = eduInfo.graduateTime {
                            cell.timeLabel.text = String("\(admissionTime)-\(graduateTime)")
                        }
                        return cell
                    }
                }
            }
            if detailItem.type == .certificateInfo {
                if let quaList = educationInfo?.quaList {
                    // 第一行是标题
                    let quaInfo:YHQualificationInfo = quaList[indexPath.row-1]
                    let cell = tableView.dequeueReusableCell(withIdentifier: YHFormItemEnterDetailCell.cellReuseIdentifier, for: indexPath) as! YHFormItemEnterDetailCell
                    cell.title = "证书标题"
                    if let qualification = quaInfo.qualification, !qualification.isEmpty {
                        cell.title = qualification
                    }
                    if quaInfo.vacantNum > 0 {
                        cell.detailLabel.text = String(format: "有%d项未填", quaInfo.vacantNum)
                    } else {
                        cell.detailLabel.text = "已填完".local
                    }
                    return cell
                }
            }
        }
        
        let cell = tableView.dequeueReusableCell(withIdentifier: "UITableViewCell", for: indexPath)
        return cell
    }
    
    func tableView(_ tableView: UITableView, willDisplay cell: UITableViewCell, forRowAt indexPath: IndexPath) {
        
        if indexPath.section >= items.count { return  }
        let arr:[YHFormItemProtocol] = items[indexPath.section]
        if indexPath.row >= arr.count {  return }
        
        createCorner(cell: cell, arr: arr, indexPath: indexPath)
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        
        let arr = items[indexPath.section]
        let item:YHFormItemProtocol = arr[indexPath.row]
        
        if item is YHFormTitleItem { // 是标题
            return 52.0
        } else if item is YHFormAddItem { // 新增子女兄妹
            return 70.0
        }
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        return UIView()
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        return 14.0
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
        let arr = items[indexPath.section]
        let item:YHFormItemProtocol = arr[indexPath.row]
        
        // 标题
        if item is YHFormTitleItem {
            return
        }
        
        if item is YHFormAddItem {
            let detailItem = item as! YHFormAddItem
            if detailItem.type == .addEducation {
                let vc = YHEducationDetailVC()
                self.navigationController?.pushViewController(vc)
                
            } else if detailItem.type == .addCertificateInfo {
                let vc = YHProfessionalQualificationVC()
                self.navigationController?.pushViewController(vc)
            }
            return
        }
        
        if item is YHFormDetailItem {
            let detailItem = item as! YHFormDetailItem
            if detailItem.type == .educationInfo { // 学历
                let vc = YHEducationDetailVC()
                self.navigationController?.pushViewController(vc)
                return
            }
            if detailItem.type == .certificateInfo { // 证书
                let vc = YHProfessionalQualificationVC()
                self.navigationController?.pushViewController(vc)
                return
            }
        }
        
        let vc = YHEducationDetailVC()
        self.navigationController?.pushViewController(vc)
    }
    
    func createDefaultCell(_ indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "UITableViewCell", for: indexPath)
        return cell
    }
        
    func createCorner(cell:UITableViewCell, arr:Array<Any>, indexPath:IndexPath) {
        // 设置每块section圆角
        if (indexPath.row == 0) {
            let corner = UIRectCorner(rawValue: UIRectCorner.topLeft.rawValue | UIRectCorner.topRight.rawValue)
            cell.createCorner(CGSizeMake(12.0, 12.0), corner)
            
        } else if (indexPath.row == arr.count-1) {
            let corner = UIRectCorner(rawValue: UIRectCorner.bottomLeft.rawValue | UIRectCorner.bottomRight.rawValue)
            cell.createCorner(CGSizeMake(12.0, 12.0), corner)
            
        } else {
            cell.layer.mask = nil
        }
    }
}

extension YHEducationalQualificationVC {
    
    // 请求家庭成员信息
    func requestEducationInfo() {
        
        self.educationRequest.requestEducationInfo(params: ["order_id": self.orderId!]) {
            [weak self] success, error in
            guard let self = self else { return }
            if success {
                educationInfo = self.educationRequest.educationInfo
                loadInfo()
            }
        }
    }
}


